@@ -1,10 +1,10 @@
-use anyhow::{format_err, Error};
+use anyhow::Error;
 use isocountry::CountryCode;
 use log::error;
 use reqwest::{Client, Url};
 use stack_string::StackString;
 use std::{
-    fmt,
+    fmt::{self, Write},
     hash::{Hash, Hasher},
 };
 
@@ -90,17 +90,15 @@ impl PartialEq for WeatherApi {
 
 impl fmt::Debug for WeatherApi {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(
-            f,
-            "WeatherApi(key={},endpoint={})",
-            self.api_key, self.api_endpoint
-        )
+        let api_key = &self.api_key;
+        let api_endpoint = &self.api_endpoint;
+        write!(f, "WeatherApi(key={api_key},endpoint={api_endpoint})")
     }
 }
 
 impl Hash for WeatherApi {
     fn hash<H: Hasher>(&self, state: &mut H) {
-        format!("{:?}", self).hash(state);
+        format!("{self:?}").hash(state);
     }
 }
 
@@ -121,7 +119,7 @@ impl WeatherCommands {
 
 impl fmt::Display for WeatherCommands {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", self.to_str())
+        f.write_str(self.to_str())
     }
 }
 
@@ -183,8 +181,9 @@ impl WeatherApi {
                 country_code,
             } => {
                 let country_code = country_code.map_or("US", |c| c.alpha2());
+                let zipcode_str = StackString::from_display(zipcode);
                 vec![
-                    ("zip", zipcode.to_string().into()),
+                    ("zip", zipcode_str),
                     ("country_code", country_code.into()),
                     ("APPID", self.api_key.clone()),
                 ]
@@ -196,11 +195,15 @@ impl WeatherApi {
             WeatherLocation::LatLon {
                 latitude,
                 longitude,
-            } => vec![
-                ("lat", latitude.to_string().into()),
-                ("lon", longitude.to_string().into()),
-                ("APPID", self.api_key.clone()),
-            ],
+            } => {
+                let latitude_str = StackString::from_display(latitude);
+                let longitude_str = StackString::from_display(longitude);
+                vec![
+                    ("lat", latitude_str),
+                    ("lon", longitude_str),
+                    ("APPID", self.api_key.clone()),
+                ]
+            }
         };
         Ok(options)
     }
@@ -210,7 +213,9 @@ impl WeatherApi {
         command: WeatherCommands,
         options: &[(&'static str, StackString)],
     ) -> Result<T, Error> {
-        let base_url = format!("https://{}/{}{}", self.api_endpoint, self.api_path, command);
+        let api_endpoint = &self.api_endpoint;
+        let api_path = &self.api_path;
+        let base_url = format!("https://{api_endpoint}/{api_path}{command}");
         let url = Url::parse_with_params(&base_url, options)?;
         self.client
             .get(url)
@@ -281,7 +286,7 @@ mod tests {
         assert_eq!(api, api2);
 
         assert_eq!(
-            format!("{:?}", api),
+            format!("{api:?}"),
             "WeatherApi(key=8675309,endpoint=api.openweathermap.org)".to_string()
         );
 
